@@ -12,10 +12,10 @@
 #'
 #' `variables` identifies the focal regressors whose "effect" we are interested in. `comparison` determines how predictions with different regressor values are compared (difference, ratio, odds, etc.). The `newdata` argument and the `datagrid()` function control where statistics are evaluated in the predictor space: "at observed values", "at the mean", "at representative values", etc.
 #'
-#' See the comparisons vignette and package website for worked examples and case studies:
+#' See the comparisons chapter on the package website for worked examples and case studies:
 #'
-#' * <https://marginaleffects.com/chapters/comparisons.html>
-#' * <https://marginaleffects.com/>
+#' * [https://marginaleffects.com/chapters/comparisons.html](https://marginaleffects.com/chapters/comparisons.html)
+#' * [https://marginaleffects.com/](https://marginaleffects.com/)
 #'
 #' @inheritParams slopes
 #' @inheritParams predictions
@@ -49,7 +49,7 @@
 #'   - Examples:
 #'     + `variables = list(gear = "pairwise", hp = 10)`
 #'     + `variables = list(gear = "sequential", hp = c(100, 120))`
-#'     + `variables = list(hp = \(x) data.frame(low = x - 5, high = x + 10))`
+#'     + `variables = list(hp = function(x) data.frame(low = x - 5, high = x + 10))`
 #'     + See the Examples section below for more.
 #' @param newdata Grid of predictor values at which we evaluate the comparisons.
 #' + Warning: Avoid modifying your dataset between fitting the model and calling a `marginaleffects` function. This can sometimes lead to unexpected results.
@@ -95,23 +95,9 @@
 #' @template order_of_operations
 #' @template parallel
 #' @template options
-#'
-#' @return A `data.frame` with one row per observation (per term/group) and several columns:
-#' * `rowid`: row number of the `newdata` data frame
-#' * `type`: prediction type, as defined by the `type` argument
-#' * `group`: (optional) value of the grouped outcome (e.g., categorical outcome models)
-#' * `term`: the variable whose marginal effect is computed
-#' * `dydx`: slope of the outcome with respect to the term, for a given combination of predictor values
-#' * `std.error`: standard errors computed by via the delta method.
-#' * `p.value`: p value associated to the `estimate` column. The null is determined by the `hypothesis` argument (0 by default), and p values are computed before applying the `transform` argument.
-#' * `s.value`: Shannon information transforms of p values. How many consecutive "heads" tosses would provide the same amount of evidence (or "surprise") against the null hypothesis that the coin is fair? The purpose of S is to calibrate the analyst's intuition about the strength of evidence encoded in p against a well-known physical phenomenon. See Greenland (2019) and Cole et al. (2020).
-#' * `conf.low`: lower bound of the confidence interval (or equal-tailed interval for bayesian models)
-#' * `conf.high`: upper bound of the confidence interval (or equal-tailed interval for bayesian models)
-#'
-#' See `?print.marginaleffects` for printing options.
+#' @template return
 #'
 #' @examplesIf interactive() || isTRUE(Sys.getenv("R_DOC_BUILD") == "true")
-#' @examples
 #' library(marginaleffects)
 #'
 #' # Linear model
@@ -131,7 +117,7 @@
 #' comparisons(mod, newdata = "mean")
 #'
 #' # Contrasts between marginal means
-#' comparisons(mod, newdata = "marginalmeans")
+#' comparisons(mod, newdata = "balanced")
 #'
 #' # Contrasts at user-specified values
 #' comparisons(mod, newdata = datagrid(am = 0, gear = tmp$gear))
@@ -153,10 +139,10 @@
 #' dat <- mtcars
 #' dat$new_hp <- 49 * (dat$hp - min(dat$hp)) / (max(dat$hp) - min(dat$hp)) + 1
 #' modlog <- lm(mpg ~ log(new_hp) + factor(cyl), data = dat)
-#' fdiff <- \(x) data.frame(x, x + 10)
+#' fdiff <- function(x) data.frame(x, x + 10)
 #' avg_comparisons(modlog, variables = list(new_hp = fdiff))
 #'
-#' # Adjusted Risk Ratio: see the contrasts vignette
+#' # Adjusted Risk Ratio
 #' mod <- glm(vs ~ mpg, data = mtcars, family = binomial)
 #' avg_comparisons(mod, comparison = "lnratioavg", transform = exp)
 #'
@@ -243,20 +229,22 @@ comparisons <- function(model,
                         wts = FALSE,
                         hypothesis = NULL,
                         equivalence = NULL,
-                        p_adjust = NULL,
                         df = Inf,
                         eps = NULL,
                         numderiv = "fdforward",
                         ...) {
+
+  call_attr <- construct_call(model, "comparisons")
+
+  # multiple imputation
+  if (inherits(model, c("mira", "amest"))) {
+      out <- process_imputation(model, call_attr)
+      return(out)
+  }
+
   dots <- list(...)
 
-  # very early, before any use of newdata
-  # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
-  scall <- rlang::enquo(newdata)
-  newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
-
   # extracting modeldata repeatedly is slow.
-  # checking dots allows marginalmeans to pass modeldata to predictions.
   if (isTRUE(by)) {
     modeldata <- get_modeldata(model,
       additional_variables = FALSE,
@@ -268,33 +256,14 @@ comparisons <- function(model,
       modeldata = dots[["modeldata"]],
       wts = wts)
   }
-
-  # build call: match.call() doesn't work well in *apply()
-  # after sanitize_newdata_call
-  call_attr <- c(
-    list(
-      name = "comparisons",
-      model = model,
-      newdata = newdata,
-      variables = variables,
-      type = type,
-      vcov = vcov,
-      by = by,
-      conf_level = conf_level,
-      comparison = comparison,
-      transform = transform,
-      cross = cross,
-      wts = wts,
-      hypothesis = hypothesis,
-      equivalence = equivalence,
-      p_adjust = p_adjust,
-      df = df),
-    dots)
-  if ("modeldata" %in% names(dots)) {
-    call_attr[["modeldata"]] <- modeldata
+  if ("modeldata" %in% ...names()) {
+      call_attr[["modeldata"]] <- modeldata
   }
-  call_attr <- do.call("call", call_attr)
 
+  # very early, before any use of newdata
+  # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
+  scall <- rlang::enquo(newdata)
+  newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
 
   # required by stubcols later, but might be overwritten
   bycols <- NULL
@@ -305,7 +274,6 @@ comparisons <- function(model,
   conf_level <- sanitize_conf_level(conf_level, ...)
   checkmate::assert_number(eps, lower = 1e-10, null.ok = TRUE)
   numderiv <- sanitize_numderiv(numderiv)
-  sanity_equivalence_p_adjust(equivalence, p_adjust)
   model <- sanitize_model(
     model = model,
     newdata = newdata,
@@ -318,11 +286,7 @@ comparisons <- function(model,
   type <- sanitize_type(model = model, type = type, calling_function = "comparisons")
   sanity_comparison(comparison)
 
-  # multiple imputation
-  if (inherits(model, c("mira", "amest"))) {
-    out <- process_imputation(model, call_attr)
-    return(out)
-  }
+
 
   # transforms
   comparison_label <- transform_label <- NULL
@@ -338,8 +302,6 @@ comparisons <- function(model,
     transform_label <- names(transform)
   }
 
-  marginalmeans <- isTRUE(checkmate::check_choice(newdata, choices = "marginalmeans"))
-
 
   newdata <- sanitize_newdata(
     model = model,
@@ -424,10 +386,9 @@ comparisons <- function(model,
     newdata = newdata,
     variables = predictors,
     cross = cross,
-    marginalmeans = marginalmeans,
     modeldata = modeldata)
   dots[["modeldata"]] <- NULL # dont' pass twice
-  args <- c(args, dots)
+  args <- utils::modifyList(args, dots)
   contrast_data <- do.call("get_contrast_data", args)
 
   args <- list(model,
@@ -439,11 +400,10 @@ comparisons <- function(model,
     lo = contrast_data[["lo"]],
     wts = contrast_data[["original"]][["marginaleffects_wts_internal"]],
     by = by,
-    marginalmeans = marginalmeans,
     cross = cross,
     hypothesis = hypothesis,
     modeldata = modeldata)
-  args <- c(args, dots)
+  args <- utils::modifyList(args, dots)
   mfx <- do.call("get_contrasts", args)
 
   hyp_by <- attr(mfx, "hypothesis_function_by")
@@ -464,7 +424,6 @@ comparisons <- function(model,
       newdata = newdata,
       index = idx,
       variables = predictors,
-      marginalmeans = marginalmeans,
       hypothesis = hypothesis,
       hi = contrast_data$hi,
       lo = contrast_data$lo,
@@ -473,7 +432,7 @@ comparisons <- function(model,
       eps = eps,
       cross = cross,
       numderiv = numderiv)
-    args <- c(args, dots)
+    args <- utils::modifyList(args, dots)
     se <- do.call("get_se_delta", args)
     J <- attr(se, "jacobian")
     attr(se, "jacobian") <- NULL
@@ -511,7 +470,6 @@ comparisons <- function(model,
     draws = draws,
     estimate = "estimate",
     null_hypothesis = hypothesis_null,
-    p_adjust = p_adjust,
     model = model)
 
   # clean rows and columns
@@ -547,12 +505,16 @@ comparisons <- function(model,
     get_marginaleffects_attributes(newdata, include_regex = "^newdata.*class|explicit|matrix|levels"))
 
   # Global option for lean return object
-  lean = getOption("marginaleffects_lean", default = FALSE)
+  lean <- getOption("marginaleffects_lean", default = FALSE)
 
   # Only add (potentially large) attributes if lean is FALSE
+  # extra attributes needed for print method, even with lean return object
+  attr(out, "conf_level") <- conf_level
+  attr(out, "by") <- by
+  attr(out, "lean") <- lean
+  attr(out, "vcov.type") <- vcov.type
   if (isTRUE(lean)) {
-    for (a in setdiff(names(attributes(out)), c("names", "row.names", "class"))) attr(out, a) = NULL
-    attr(out, "lean") <- TRUE
+    for (a in setdiff(names(attributes(out)), c("names", "row.names", "class"))) attr(out, a) <- NULL
   } else {
     # other attributes
     attr(out, "newdata") <- newdata
@@ -570,8 +532,6 @@ comparisons <- function(model,
     attr(out, "comparison_label") <- comparison_label
     attr(out, "hypothesis_by") <- hyp_by
     attr(out, "transform_label") <- transform_label
-    attr(out, "conf_level") <- conf_level
-    attr(out, "by") <- by
 
     if (inherits(model, "brmsfit")) {
       insight::check_if_installed("brms")
@@ -601,15 +561,14 @@ avg_comparisons <- function(model,
                             wts = FALSE,
                             hypothesis = NULL,
                             equivalence = NULL,
-                            p_adjust = NULL,
                             df = Inf,
                             eps = NULL,
                             numderiv = "fdforward",
                             ...) {
   # order of the first few paragraphs is important
   # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
-  scall <- rlang::enquo(newdata)
-  newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
+  # scall <- rlang::enquo(newdata)
+  # newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
 
   # Bootstrap
   out <- inferences_dispatch(
@@ -622,24 +581,28 @@ avg_comparisons <- function(model,
     return(out)
   }
 
-  out <- comparisons(
-    model = model,
-    newdata = newdata,
-    variables = variables,
-    type = type,
-    vcov = vcov,
-    by = by,
-    conf_level = conf_level,
-    comparison = comparison,
-    transform = transform,
-    cross = cross,
-    wts = wts,
-    hypothesis = hypothesis,
-    equivalence = equivalence,
-    p_adjust = p_adjust,
-    df = df,
-    eps = eps,
-    ...)
+  #Construct comparisons() call
+  call_attr <- construct_call(model, "comparisons")
+
+  out <- eval.parent(call_attr)
+
+  # out <- comparisons(
+  #   model = model,
+  #   newdata = newdata,
+  #   variables = variables,
+  #   type = type,
+  #   vcov = vcov,
+  #   by = by,
+  #   conf_level = conf_level,
+  #   comparison = comparison,
+  #   transform = transform,
+  #   cross = cross,
+  #   wts = wts,
+  #   hypothesis = hypothesis,
+  #   equivalence = equivalence,
+  #   df = df,
+  #   eps = eps,
+  #   ...)
 
   return(out)
 }
