@@ -26,14 +26,14 @@
 #' If `datagrid` is used in a `predictions()`, `comparisons()`, or `slopes()` call as the
 #' `newdata` argument, the model is automatically inserted in the `model` argument of `datagrid()`
 #' call, and users do not need to specify either the `model` or `newdata` arguments. The same behavior will occur when the value supplied to `newdata=` is a function call which starts with "datagrid". This is intended to allow users to create convenience shortcuts like:
-#' 
+#'
 #' \preformatted{
 #' library(marginaleffects)
 #' mod <- lm(mpg ~ am + vs + factor(cyl) + hp, mtcars)
 #' datagrid_bal <- function(...) datagrid(..., grid_type = "balanced")
 #' predictions(model, newdata = datagrid_bal(cyl = 4))
 #' }
-#' 
+#'
 #'
 #' If users supply a model, the data used to fit that model is retrieved using
 #' the `insight::get_data` function.
@@ -85,8 +85,6 @@ datagrid <- function(
     FUN_binary = NULL,
     FUN_other = NULL) {
 
-    dots <- list(...)
-
     # backward compatibility: 20231220
     if (identical(grid_type, "typical")) {
         grid_type <- "mean_or_mode"
@@ -105,6 +103,8 @@ datagrid <- function(
     checkmate::assert_data_frame(newdata, null.ok = TRUE)
     checkmate::assert_flag(response)
 
+    explicit <- c(...names(), by)
+
     if (grid_type == "mean_or_mode") {
         if (is.null(FUN_character)) FUN_character <- get_mode
         if (is.null(FUN_logical)) FUN_logical <- get_mode
@@ -131,7 +131,7 @@ datagrid <- function(
         args <- list(
             model = model,
             newdata = newdata)
-        args <- c(dots, args)
+        args <- c(list(...), args)
         out <- do.call("datagridcf_internal", args)
         return(out)
     }
@@ -168,23 +168,14 @@ datagrid <- function(
             newdata_list[[i]] <- do.call(datagrid_engine, args)
         }
 
-        # Issue 1058: missing attributes with `by`
-        at <- attributes(newdata_list[[1]])
-
         out <- data.table::rbindlist(newdata_list)
         data.table::setDF(out)
 
-        # Issue 1058: missing attributes with `by`
-        # overwriting everything corrupts the data frame
-        for (n in names(at)) {
-            if (!n %in% names(attributes(out))) {
-                attr(out, n) <- at[[n]]
-            }
-        }
+        attr(out, "explicit") <- explicit
 
         return(out)
     }
-    
+
     out <- datagrid_engine(...,
                 model = model,
                 newdata = newdata,
@@ -201,6 +192,7 @@ datagrid <- function(
         out$rowid <- seq_len(nrow(out))
     }
 
+    attr(out, "explicit") <- explicit
     return(out)
 }
 
@@ -220,8 +212,6 @@ datagrid_engine <- function(
     FUN_other = function(x) mean(x, na.rm = TRUE),
     by = NULL) {
 
-    dots <- list(...)
-   
     tmp <- prep_datagrid(..., model = model, newdata = newdata, by = by)
 
     at <- tmp$at
@@ -230,7 +220,7 @@ datagrid_engine <- function(
     variables_manual <- names(at)
     variables_automatic <- tmp$automatic
 
-    # usually we don't want the response in the grid, but 
+    # usually we don't want the response in the grid, but
     # sometimes there are two responses and we need one of them:
     # brms::brm(y | trials(n) ~ x + w + z)
     if (!is.null(model) && isFALSE(response)) {
@@ -306,17 +296,9 @@ datagrid_engine <- function(
     args <- c(out, list(sorted = FALSE))
     out <- do.call("fun", args)
 
-    # na.omit destroys attributes, and we need the "factor" attribute
-    # created by insight::get_data
-    for (n in names(out)) {
-        attr(out, "marginaleffects_variable_class") <- attr(dat, "marginaleffects_variable_class")
-    }
-
     # better to assume "standard" class as output
     data.table::setDF(out)
 
-    attr(out, "variables_datagrid") <- names(dots)
-
     return(out)
 }
 
@@ -327,9 +309,7 @@ datagridcf_internal <- function(
     model = NULL,
     newdata = NULL) {
 
-    dots <- list(...)
-
-    if (length(dots) == 0) {
+    if (...length() == 0) {
         insight::format_error("Users must specify variable values when `grid_type='counterfactual'")
     }
 
@@ -373,7 +353,7 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL, by = NULL) {
     checkmate::assert_data_frame(newdata, null.ok = TRUE)
 
     at <- list(...)
-    
+
     # e.g., mlogit vignette we plot by group, but group is of length 0 because
     # we don't know how many groups there are until we make the first
     # prediction.
@@ -393,14 +373,14 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL, by = NULL) {
         insight::format_error(msg)
     }
 
-    # newdata before model: if user supplies newdata explicitly, they might want 
+    # newdata before model: if user supplies newdata explicitly, they might want
     # all columns for something like `hypothesis = function()`
     if (!is.null(newdata)) {
         variables_list <- NULL
         variables_all <- colnames(newdata)
         newdata <- set_variable_class(modeldata = newdata, model = model)
     } else if (!is.null(model)) {
-        variables_list <- insight::find_variables(model)
+        variables_list <- insight::find_variables(model, verbose = FALSE)
         variables_all <- unlist(variables_list, recursive = TRUE)
         # weights are not extracted by default
         variables_all <- c(variables_all, insight::find_weights(model))
@@ -419,7 +399,7 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL, by = NULL) {
     # subset columns, otherwise it can be ultra expensive to compute summaries for every variable. But do the expensive thing anyway if `newdata` is supplied explicitly by the user, or in counterfactual grids.
     if (!is.null(model) && is.null(newdata)) {
         variables_sub <- c(
-            hush(insight::find_variables(model, flatten = TRUE)),
+            hush(insight::find_variables(model, flatten = TRUE, verbose = FALSE)),
             hush(unlist(insight::find_weights(model), use.names = FALSE))) # glmmTMB needs weights column for predictions
         variables_sub <- c(variables_sub, variables_manual)
         variables_sub <- c(variables_sub, c("marginaleffects_wts_internal", "rowid_dedup"))
@@ -476,10 +456,10 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL, by = NULL) {
             }
         }
     }
-    
+
     # cluster identifiers will eventually be treated as factors
     if (!is.null(model)) {
-        v <- insight::find_variables(model)
+        v <- insight::find_variables(model, verbose = FALSE)
         v <- unlist(v[names(v) %in% c("cluster", "strata")], recursive = TRUE)
         variables_cluster <- c(v, insight::find_random(model, flatten = TRUE))
     } else {
@@ -487,7 +467,7 @@ prep_datagrid <- function(..., model = NULL, newdata = NULL, by = NULL) {
     }
 
     data.table::setDT(newdata)
-    
+
     out <- list("newdata" = newdata,
                 "at" = at,
                 "all" = variables_all,
