@@ -1,9 +1,9 @@
 #' Get a named variance-covariance matrix from a model object
 #'
+#' Mostly for internal use, but can be useful because the output is consistent across model classes.
 #' @inheritParams slopes
 #' @return A named square matrix of variance and covariances. The names must match the coefficient names.
 #' @rdname get_vcov
-#' @keywords internal
 #' @export
 get_vcov <- function(model, ...) {
   UseMethod("get_vcov", model)
@@ -105,7 +105,8 @@ get_varcov_args <- function(model, vcov) {
     return(out)
   }
 
-  if (isTRUE(vcov == "satterthwaite") || isTRUE(vcov == "kenward-roger")) {
+  if (isTRUE(checkmate::check_choice(vcov, "satterthwaite")) ||
+    isTRUE(checkmate::check_choice(vcov, "kewnard-roger"))) {
     if (!isTRUE(inherits(model, "lmerMod")) && !isTRUE(inherits(model, "lmerModTest"))) {
       msg <- "Satterthwaite and Kenward-Roger corrections are only available for linear mixed effects models from the `lme4` package, and objects of class `lmerMod` or `lmerModTest`."
       stop(msg, call. = FALSE)
@@ -156,3 +157,30 @@ get_vcov_label <- function(vcov) {
   )
   return(out)
 }
+
+
+#' internal get_vcov
+#'
+#' @export
+#' @noRd
+get_vcov.comparisons <- function(model, ...) {
+  stats::vcov(model)
+}
+
+#' internal get_vcov
+#'
+#' @export
+#' @noRd
+get_vcov.slopes <- get_vcov.comparisons
+
+#' internal get_vcov
+#'
+#' @export
+#' @noRd
+get_vcov.hypotheses <- get_vcov.comparisons
+
+#' internal get_vcov
+#'
+#' @export
+#' @noRd
+get_vcov.predictions <- get_vcov.comparisons
