@@ -10,14 +10,13 @@ supported_engine <- function(x) {
 #' @rdname set_coef
 #' @export
 set_coef.model_fit <- function(model, coefs, ...) {
+    if (!"fit" %in% names(model)) {
+        return(model)
+    }
+
+    model$fit <- set_coef(model$fit, coefs, ...)
 
-  if (!"fit" %in% names(model)) {
     return(model)
-  }
-
-  model$fit <- set_coef(model$fit, coefs, ...)
-
-  return(model)
 }
 
 
@@ -42,13 +41,12 @@ get_predict.model_fit <- function(model, newdata, type = NULL, ...) {
     if (type == "numeric") {
         v <- intersect(c(".pred", ".pred_res"), colnames(out))[1]
         out <- data.frame(rowid = seq_len(nrow(out)), estimate = out[[v]])
-
     } else if (type == "class") {
         out <- data.frame(rowid = seq_len(nrow(out)), estimate = out[[".pred_class"]])
-
     } else if (type == "prob") {
         colnames(out) <- substr(colnames(out), 7, nchar(colnames(out)))
         out$rowid <- seq_len(nrow(out))
+        data.table::setDT(out)
         out <- data.table::melt(
             out,
             id.vars = "rowid",
