@@ -7,9 +7,17 @@
 utils::globalVariables(c(
   "marginaleffects_contrast_hi",
   "marginaleffects_contrast_lo",
+  "..lab_cols",
+  "..hypothesis_by",
+  "marginaleffects_unique_labels",
+  "..lab",
+  "..nd",
   "..bycols",
+  "..by",
   "..to_keep",
   "..cols",
+  "..col_x",
+  "..col_newdata",
   "..idx_by",
   "..idx_hi",
   "..cl",
