@@ -32,7 +32,7 @@
 #' @template type
 #' @return A `ggplot2` object or data frame (if `draw=FALSE`)
 #' @export
-#' @examples
+#' @examplesIf interactive() || isTRUE(Sys.getenv("R_DOC_BUILD") == "true")
 #' mod <- lm(mpg ~ hp + wt, data = mtcars)
 #' plot_predictions(mod, condition = "wt")
 #'
@@ -43,6 +43,16 @@
 #'
 #' plot_predictions(mod, condition = list("hp", wt = range))
 #'
+#' # marginal predictions
+#' mod <- lm(mpg ~ hp * am, data = mtcars)
+#' plot_predictions(mod, by = "am")
+#'
+#' # marginal predictions on a counterfactual grid
+#' plot_predictions(mod,
+#'   by = "am",
+#'   newdata = datagrid(am = 0:1, grid_type = "counterfactual")
+#' )
+#'
 plot_predictions <- function(model,
                              condition = NULL,
                              by = NULL,
@@ -57,18 +67,17 @@ plot_predictions <- function(model,
                              gray = getOption("marginaleffects_plot_gray", default = FALSE),
                              draw = TRUE,
                              ...) {
-  dots <- list(...)
 
   checkmate::assert_number(points, lower = 0, upper = 1)
 
-  if ("variables" %in% names(dots)) {
+  if ("variables" %in% ...names()) {
     insight::format_error("The `variables` argument is not supported by this function.")
   }
-  if ("effect" %in% names(dots)) {
+  if ("effect" %in% ...names()) {
     insight::format_error("The `effect` argument is not supported by this function.")
   }
-  if ("transform_post" %in% names(dots)) { # backward compatibility
-    transform <- dots[["transform_post"]]
+  if ("transform_post" %in% ...names()) { # backward compatibility
+      transform <- ...elt(match("transform_post", ...names())[1L])
   }
 
   if (inherits(model, "mira") && is.null(newdata)) {
@@ -94,7 +103,8 @@ plot_predictions <- function(model,
   modeldata <- get_modeldata(
     model,
     additional_variables = c(names(condition), by),
-    wts = wts)
+    wts = wts
+  )
 
   # mlr3 and tidymodels
   if (is.null(modeldata) || nrow(modeldata) == 0) {
@@ -117,7 +127,8 @@ plot_predictions <- function(model,
       transform = transform,
       modeldata = modeldata,
       wts = wts,
-      ...)
+      ...
+    )
   }
 
   # marginal
@@ -129,7 +140,8 @@ plot_predictions <- function(model,
       newdata = newdata,
       modeldata = modeldata,
       by = by,
-      wts = wts)
+      wts = wts
+    )
 
     # tidymodels & mlr3
     if (is.null(modeldata)) {
@@ -146,7 +158,8 @@ plot_predictions <- function(model,
       transform = transform,
       newdata = newdata,
       modeldata = modeldata,
-      ...)
+      ...
+    )
     v_x <- by[[1]]
     v_color <- hush(by[[2]])
     v_facet_1 <- hush(by[[3]])
@@ -174,14 +187,16 @@ plot_predictions <- function(model,
     modeldata = modeldata,
     dv = dv,
     rug = rug,
-    gray = gray)
+    gray = gray
+  )
 
   p <- p + ggplot2::labs(
     x = v_x,
     y = dv,
     color = v_color,
     fill = v_color,
-    linetype = v_color)
+    linetype = v_color
+  )
 
   # attach model data for each of use
   attr(p, "modeldata") <- modeldata
