@@ -70,22 +70,8 @@
 #' @template order_of_operations
 #' @template parallel
 #' @template options
-#'
-#' @return A `data.frame` with one row per observation and several columns:
-#' * `rowid`: row number of the `newdata` data frame
-#' * `type`: prediction type, as defined by the `type` argument
-#' * `group`: (optional) value of the grouped outcome (e.g., categorical outcome models)
-#' * `estimate`: predicted outcome
-#' * `std.error`: standard errors computed using the delta method.
-#' * `p.value`: p value associated to the `estimate` column. The null is determined by the `hypothesis` argument (0 by default), and p values are computed before applying the `transform` argument. For models of class `feglm`, `Gam`, `glm` and `negbin`, p values are computed on the link scale by default unless the `type` argument is specified explicitly.
-#' * `s.value`: Shannon information transforms of p values. How many consecutive "heads" tosses would provide the same amount of evidence (or "surprise") against the null hypothesis that the coin is fair? The purpose of S is to calibrate the analyst's intuition about the strength of evidence encoded in p against a well-known physical phenomenon. See Greenland (2019) and Cole et al. (2020).
-#' * `conf.low`: lower bound of the confidence interval (or equal-tailed interval for bayesian models)
-#' * `conf.high`: upper bound of the confidence interval (or equal-tailed interval for bayesian models)
-#'
-#' See `?print.marginaleffects` for printing options.
-#'
+#' @template return
 #' @examplesIf interactive() || isTRUE(Sys.getenv("R_DOC_BUILD") == "true")
-#' @examples
 #' # Adjusted Prediction for every row of the original dataset
 #' mod <- lm(mpg ~ hp + factor(cyl), data = mtcars)
 #' pred <- predictions(mod)
@@ -165,7 +151,8 @@
 #' nom <- multinom(factor(gear) ~ mpg + am * vs, data = mtcars, trace = FALSE)
 #'
 #' # first 5 raw predictions
-#' predictions(nom, type = "probs") |> head()
+#' p <- predictions(nom, type = "probs")
+#' head(p)
 #'
 #' # average predictions
 #' avg_predictions(nom, type = "probs", by = "group")
@@ -198,68 +185,58 @@ predictions <- function(model,
                         transform = NULL,
                         hypothesis = NULL,
                         equivalence = NULL,
-                        p_adjust = NULL,
                         df = Inf,
                         numderiv = "fdforward",
                         ...) {
-  dots <- list(...)
 
-  if ("transform_post" %in% names(dots)) {
-    transform <- dots[["transform_post"]]
+  if ("cross" %in% ...names()) {
+    insight::format_error("The `cross` argument is not available in this function.")
+  }
+
+  call_attr <- construct_call(model, "predictions")
+
+  if ("transform_post" %in% ...names()) {
+    transform <- ...elt(match("transform_post", ...names())[1L])
+    call_attr[["transform"]] <- transform
     insight::format_warning("The `transform_post` argument is deprecated. Use `transform` instead.")
   }
 
+  # multiple imputation
+  if (inherits(model, c("mira", "amest"))) {
+    out <- process_imputation(model, call_attr)
+    return(out)
+  }
+
+  dots <- list(...)
+
+  # extracting modeldata repeatedly is slow.
+  if (isTRUE(by)) {
+    modeldata <- get_modeldata(model,
+                               additional_variables = FALSE,
+                               modeldata = dots[["modeldata"]],
+                               wts = wts)
+  } else {
+    modeldata <- get_modeldata(model,
+                               additional_variables = by,
+                               modeldata = dots[["modeldata"]],
+                               wts = wts)
+  }
+
+  if ("modeldata" %in% ...names()) {
+    call_attr[["modeldata"]] <- modeldata
+  }
+
+  sanity_reserved(model, modeldata)
+
   # very early, before any use of newdata
   # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
   scall <- rlang::enquo(newdata)
   newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
 
-  if ("cross" %in% names(dots)) {
-    insight::format_error("The `cross` argument is not available in this function.")
-  }
-
-  # extracting modeldata repeatedly is slow.
-  # checking dots allows marginalmeans to pass modeldata to predictions.
-  if (isTRUE(by)) {
-    modeldata <- get_modeldata(model,
-      additional_variables = FALSE,
-      modeldata = dots[["modeldata"]],
-      wts = wts)
-  } else {
-    modeldata <- get_modeldata(model,
-      additional_variables = by,
-      modeldata = dots[["modeldata"]],
-      wts = wts)
-  }
-
-  # build call: match.call() doesn't work well in *apply()
-  # after sanitize_newdata_call
-  call_attr <- c(
-    list(
-      name = "predictions",
-      model = model,
-      newdata = newdata,
-      variables = variables,
-      vcov = vcov,
-      conf_level = conf_level,
-      type = type,
-      by = by,
-      byfun = byfun,
-      wts = wts,
-      transform = transform,
-      hypothesis = hypothesis,
-      df = df),
-    dots)
-  if ("modeldata" %in% names(dots)) {
-    call_attr[["modeldata"]] <- modeldata
-  }
-  call_attr <- do.call("call", call_attr)
-
   # sanity checks
   sanity_dots(model = model, ...)
   numderiv <- sanitize_numderiv(numderiv)
   sanity_df(df, newdata)
-  sanity_equivalence_p_adjust(equivalence, p_adjust)
   model <- sanitize_model(
     model = model,
     newdata = newdata,
@@ -272,12 +249,6 @@ predictions <- function(model,
   hypothesis <- tmp$hypothesis
   hypothesis_null <- tmp$hypothesis_null
 
-  # multiple imputation
-  if (inherits(model, c("mira", "amest"))) {
-    out <- process_imputation(model, call_attr)
-    return(out)
-  }
-
   # if type is NULL, we backtransform if relevant
   type_string <- sanitize_type(
     model = model,
@@ -358,9 +329,6 @@ predictions <- function(model,
     newdata[["idx"]] <- NULL
   }
 
-  # padding destroys `newdata` attributes, so we save them
-  newdata_attr_cache <- get_marginaleffects_attributes(newdata, include_regex = "^newdata")
-
   # mlogit uses an internal index that is very hard to track, so we don't
   # support `newdata` and assume no padding the `idx` column is necessary for
   # `get_predict` but it breaks binding, so we can't remove it in
@@ -490,7 +458,6 @@ predictions <- function(model,
       null_hypothesis = hypothesis_null,
       df = df,
       model = model,
-      p_adjust = p_adjust,
       ...)
   }
 
@@ -540,33 +507,31 @@ predictions <- function(model,
 
   data.table::setDF(out)
   class(out) <- c("predictions", class(out))
-  out <- set_marginaleffects_attributes(out, attr_cache = newdata_attr_cache)
 
   # Global option for lean return object
-  lean = getOption("marginaleffects_lean", default = FALSE)
+  lean <- getOption("marginaleffects_lean", default = FALSE)
 
-  # Only add (potentially large) attributes if lean isn't TRUE
+  # Only add (potentially large) attributes if lean is FALSE
+  # extra attributes needed for print method, even with lean return object
+  attr(out, "conf_level") <- conf_level
+  attr(out, "by") <- by
+  attr(out, "lean") <- lean
+  attr(out, "type") <- type_string
   if (isTRUE(lean)) {
-    for (a in setdiff(aa, c("names", "row.names", "class"))) attr(mfx, a) = NULL
-    attr(out, "lean") <- TRUE
+    for (a in setdiff(names(attributes(out)), c("names", "row.names", "class"))) {
+      attr(out, a) <- NULL
+    }
   } else {
     # other attributes
-    attr(out, "model") <- model
-    attr(out, "type") <- type_string
+    attr(out, "newdata") <- newdata
+    attr(out, "call") <- call_attr
     attr(out, "model_type") <- class(model)[1]
-    attr(out, "vcov.type") <- get_vcov_label(vcov)
+    attr(out, "model") <- model
     attr(out, "jacobian") <- J
     attr(out, "vcov") <- V
-    attr(out, "newdata") <- newdata
     attr(out, "weights") <- marginaleffects_wts_internal
-    attr(out, "conf_level") <- conf_level
-    attr(out, "by") <- by
-    attr(out, "call") <- call_attr
-    attr(out, "hypothesis_by") <- hyp_by
-    attr(out, "transform_label") <- names(transform)[1]
     attr(out, "transform") <- transform[[1]]
-    # save newdata for use in recall()
-    attr(out, "newdata") <- newdata
+    attr(out, "hypothesis_by") <- hyp_by
 
     if (inherits(model, "brmsfit")) {
       insight::check_if_installed("brms")
@@ -695,14 +660,13 @@ avg_predictions <- function(model,
                             transform = NULL,
                             hypothesis = NULL,
                             equivalence = NULL,
-                            p_adjust = NULL,
                             df = Inf,
                             numderiv = "fdforward",
                             ...) {
   # order of the first few paragraphs is important
   # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
-  scall <- rlang::enquo(newdata)
-  newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
+  # scall <- rlang::enquo(newdata)
+  # newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
 
   # group by focal variable automatically unless otherwise stated
   if (isTRUE(by)) {
@@ -723,22 +687,27 @@ avg_predictions <- function(model,
     return(out)
   }
 
-  out <- predictions(
-    model = model,
-    newdata = newdata,
-    variables = variables,
-    vcov = vcov,
-    conf_level = conf_level,
-    type = type,
-    by = by,
-    byfun = byfun,
-    wts = wts,
-    transform = transform,
-    hypothesis = hypothesis,
-    equivalence = equivalence,
-    p_adjust = p_adjust,
-    df = df,
-    ...)
+  #Construct predictions() call
+  call_attr <- construct_call(model, "predictions")
+  call_attr[["by"]] <- by
+
+  out <- eval.parent(call_attr)
+
+  # out <- predictions(
+  #   model = model,
+  #   newdata = newdata,
+  #   variables = variables,
+  #   vcov = vcov,
+  #   conf_level = conf_level,
+  #   type = type,
+  #   by = by,
+  #   byfun = byfun,
+  #   wts = wts,
+  #   transform = transform,
+  #   hypothesis = hypothesis,
+  #   equivalence = equivalence,
+  #   df = df,
+  #   ...)
 
   return(out)
 }
