@@ -49,27 +49,27 @@ comparison_function_dict <- list(
 
 comparison_label_dict <- list(
     "difference" = "%s - %s",
-    "differenceavg" = "mean(%s) - mean(%s)",
-    "differenceavgwts" = "mean(%s) - mean(%s)",
+    "differenceavg" = "%s - %s",
+    "differenceavgwts" = "%s - %s",
 
     "dydx" = "dY/dX",
     "eyex" = "eY/eX",
     "eydx" = "eY/dX",
     "dyex" = "dY/eX",
 
-    "dydxavg" = "mean(dY/dX)",
-    "eyexavg" = "mean(eY/eX)",
-    "eydxavg" = "mean(eY/dX)",
-    "dyexavg" = "mean(dY/eX)",
+    "dydxavg" = "dY/dX",
+    "eyexavg" = "eY/eX",
+    "eydxavg" = "eY/dX",
+    "dyexavg" = "dY/eX",
 
-    "dydxavg" = "mean(dY/dX)",
-    "eyexavg" = "mean(eY/eX)",
-    "eydxavg" = "mean(eY/dX)",
-    "dyexavg" = "mean(dY/eX)",
-    "dydxavgwts" = "mean(dY/dX)",
-    "eyexavgwts" = "mean(eY/eX)",
-    "eydxavgwts" = "mean(eY/dX)",
-    "dyexavgwts" = "mean(dY/eX)",
+    "dydxavg" = "dY/dX",
+    "eyexavg" = "eY/eX",
+    "eydxavg" = "eY/dX",
+    "dyexavg" = "dY/eX",
+    "dydxavgwts" = "dY/dX",
+    "eyexavgwts" = "eY/eX",
+    "eydxavgwts" = "eY/dX",
+    "dyexavgwts" = "dY/eX",
 
     "ratio" = "%s / %s",
     "ratioavg" = "mean(%s) / mean(%s)",
@@ -116,7 +116,9 @@ sanitize_transform <- function(x) {
 
     if (is.null(x)) {
         return(x)
-    } else if (is.function(x)) {
+    }
+
+    if (is.function(x)) {
         out <- list(x)
         names(out) <- deparse(substitute(x))
     } else if (x == "exp") {
