@@ -27,10 +27,11 @@ sanitize_variables <- function(variables,
   if (is.null(variables)) {
     # mhurdle names the variables weirdly
     if (inherits(model, "mhurdle")) {
-      predictors <- insight::find_predictors(model, flatten = TRUE)
+      predictors <- insight::find_predictors(model, flatten = TRUE, verbose = FALSE)
       predictors <- list(conditional = predictors)
     } else {
-      predictors <- insight::find_variables(model)
+      predictors <- insight::find_variables(model, verbose = FALSE)
+      predictors <- predictors[!names(predictors) %in% "response"]
     }
 
     # unsupported models like pytorch
@@ -59,28 +60,7 @@ sanitize_variables <- function(variables,
     predictors <- stats::setNames(rep(list(NULL), length(predictors)), predictors)
   }
 
-  # reserved keywords
-  # Issue #697: we used to allow "group", as long as it wasn't in
-  # `variables`, but this created problems with automatic `by=TRUE`. Perhaps
-  # I could loosen this, but there are many interactions, and the lazy way is
-  # just to forbid entirely.
-  reserved <- c(
-    "rowid", "group", "term", "contrast", "estimate",
-    "std.error", "statistic", "conf.low", "conf.high", "p.value",
-    "p.value.nonsup", "p.value.noninf", "by")
-  # if no modeldata is available, we use `newdata`, but that often has a
-  # `rowid` column. This used to break the extensions.Rmd vignette.
-  if (no_modeldata) {
-    reserved <- setdiff(reserved, "rowid")
-  }
-  bad <- unique(intersect(c(names(predictors), colnames(modeldata)), reserved))
-  if (length(bad) > 0) {
-    msg <- c(
-      "These variable names are forbidden to avoid conflicts with the outputs of `marginaleffects`:",
-      sprintf("%s", paste(sprintf('"%s"', bad), collapse = ", ")),
-      "Please rename your variables before fitting the model.")
-    insight::format_error(msg)
-  }
+  sanity_reserved(model = model, modeldata = modeldata)
 
   # when comparisons() only inludes one focal predictor, we don't need to specify it in `newdata`
   # when `variables` is numeric, we still need to include it, because in
@@ -102,7 +82,7 @@ sanitize_variables <- function(variables,
 
 
   # matrix predictors
-  mc <- attr(newdata, "newdata_matrix_columns")
+  mc <- attr(newdata, "matrix_columns")
   if (length(mc) > 0 && any(names(predictors) %in% mc)) {
     predictors <- predictors[!names(predictors) %in% mc]
     insight::format_warning("Matrix columns are not supported. Use the `variables` argument to specify valid predictors, or use a function like `drop()` to convert your matrix columns into vectors.")
@@ -326,6 +306,10 @@ sanitize_variables <- function(variables,
       predictors[[v]][["eps"]] <- eps
     } else if (is.numeric(modeldata[[v]])) {
       predictors[[v]][["eps"]] <- 1e-4 * diff(range(modeldata[[v]], na.rm = TRUE, finite = TRUE))
+      # 1-row grid has 0 range
+      if (predictors[[v]][["eps"]] == 0) {
+        predictors[[v]][["eps"]] <- 1e-4
+      }
     } else {
       predictors[[v]]["eps"] <- list(NULL)
     }
