@@ -10,8 +10,8 @@
 #'
 #' See the slopes vignette and package website for worked examples and case studies:
 #'
-#' * <https://marginaleffects.com/chapters/slopes.html>
-#' * <https://marginaleffects.com/>
+#' * [https://marginaleffects.com/chapters/slopes.html](https://marginaleffects.com/chapters/slopes.html)
+#' * [https://marginaleffects.com/](https://marginaleffects.com/)
 #'
 #' @details
 #' A "slope" or "marginal effect" is the partial derivative of the regression equation
@@ -67,39 +67,45 @@
 #' + numeric: vector of length equal to the number of rows in the original data or in `newdata` (if supplied).
 #' + FALSE: Equal weights.
 #' + TRUE: Extract weights from the fitted object with `insight::find_weights()` and use them when taking weighted averages of estimates. Warning: `newdata=datagrid()` returns a single average weight, which is equivalent to using `wts=FALSE`
-#' @param hypothesis specify a hypothesis test or custom contrast using a numeric value, vector, or matrix; a string equation; string; a formula, or a function.
-#' + Numeric:
-#'   - Single value: the null hypothesis used in the computation of Z and p (before applying `transform`).
-#'   - Vector: Weights to compute a linear combination of (custom contrast between) estimates. Length equal to the number of rows generated by the same function call, but without the `hypothesis` argument.
-#'   - Matrix: Each column is a vector of weights, as describe above, used to compute a distinct linear combination of (contrast between) estimates. The column names of the matrix are used as labels in the output.
-#' + String equation to specify linear or non-linear hypothesis tests. If the `term` column uniquely identifies rows, terms can be used in the formula. Otherwise, use `b1`, `b2`, etc. to identify the position of each parameter. The `b*` wildcard can be used to test hypotheses on all estimates. If a named vector is used, the names are used as labels in the output. Examples:
+#' @param hypothesis specify a hypothesis test or custom contrast using a number , formula, string equation, vector, matrix, or function.
+#' + Number: The null hypothesis used in the computation of Z and p (before applying `transform`).
+#' + String: Equation to specify linear or non-linear hypothesis tests. If the terms in `coef(object)` uniquely identify estimates, they can be used in the formula. Otherwise, use `b1`, `b2`, etc. to identify the position of each parameter. The `b*` wildcard can be used to test hypotheses on all estimates. If a named vector is used, the names are used as labels in the output. Examples:
 #'   - `hp = drat`
 #'   - `hp + drat = 12`
 #'   - `b1 + b2 + b3 = 0`
 #'   - `b* / b1 = 1`
-#' + String:
-#'   - "pairwise": pairwise differences between estimates in each row.
-#'   - "reference": differences between the estimates in each row and the estimate in the first row.
-#'   - "sequential": difference between an estimate and the estimate in the next row.
-#'   - "meandev": difference between an estimate and the mean of all estimates.
-#'   - "meanotherdev": difference between an estimate and the mean of all other estimates, excluding the current one.
-#'   - "revpairwise", "revreference", "revsequential": inverse of the corresponding hypotheses, as described above.
-#' + Formula:
-#'   - `comparison ~ pairs | group`
-#'   - Left-hand side determines the type of comparison to conduct: `difference` or `ratio`. If the left-hand side is empty, `difference` is chosen.
-#'   - Right-hand side determines the pairs of estimates to compare: `reference`, `sequential`, or `meandev`
-#'   - Optional: Users can supply grouping variables after a vertical bar to conduct comparisons withing subsets.
-#'   - Examples:
+#' + Formula: `lhs ~ rhs | group`
+#'   + `lhs`
+#'     - `ratio`
+#'     - `difference`
+#'     - Leave empty for default value
+#'   + `rhs`
+#'     - `pairwise` and `revpairwise`: pairwise differences between estimates in each row.
+#'     - `reference`: differences between the estimates in each row and the estimate in the first row.
+#'     - `sequential`: difference between an estimate and the estimate in the next row.
+#'     - `meandev`: difference between an estimate and the mean of all estimates.
+#'     - `meanotherdev: difference between an estimate and the mean of all other estimates, excluding the current one.
+#'     - `poly`: polynomial contrasts, as computed by the `stats::contr.poly()` function.
+#'     - `helmert`: Helmert contrasts, as computed by the `stats::contr.helmert()` function. Contrast 2nd level to the first, 3rd to the average of the first two, and so on.
+#'     - `trt_vs_ctrl`: difference between the mean of estimates (except the first) and the first estimate.
+#'     - `I(fun(x))`: custom function to manipulate the vector of estimates `x`. The function `fun()` can return multiple (potentially named) estimates.
+#'   + `group` (optional)
+#'     - Column name of `newdata`. Conduct hypothesis tests withing subsets of the data.
+#'   + Examples:
+#'      + `~ poly`
+#'      + `~ sequential | groupid`
 #'      + `~ reference`
 #'      + `ratio ~ pairwise`
 #'      + `difference ~ pairwise | groupid`
+#'      + `~ I(x - mean(x)) | groupid`
+#'      + `~ I(\(x) c(a = x[1], b = mean(x[2:3]))) | groupid`
+#' + Matrix or Vector: Each column is a vector of weights. The the output is the dot product between these vectors of weights and the vector of estimates. The matrix can have column names to label the estimates.
 #' + Function:
 #'   - Accepts an argument `x`: object produced by a `marginaleffects` function or a data frame with column `rowid` and `estimate`
 #'   - Returns a data frame with columns `term` and `estimate` (mandatory) and `rowid` (optional).
 #'   - The function can also accept optional input arguments: `newdata`, `by`, `draws`.
 #'   - This function approach will not work for Bayesian models or with bootstrapping. In those cases, it is easy to use `get_draws()` to extract and manipulate the draws directly.
-#' + See the Examples section below and the vignette: https://marginaleffects.com/chapters/hypothesis.html
-#' @param p_adjust Adjust p-values for multiple comparisons: "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", or "fdr". See [stats::p.adjust]
+#' + See the Examples section below and the vignette: [https://marginaleffects.com/chapters/hypothesis.html](https://marginaleffects.com/chapters/hypothesis.html)
 #' @param df Degrees of freedom used to compute p values and confidence intervals. A single numeric value between 1 and `Inf`. When `df` is `Inf`, the normal distribution is used. When `df` is finite, the `t` distribution is used. See [insight::get_df] for a convenient function to extract degrees of freedom. Ex: `slopes(model, df = insight::get_df(model))`
 #' @param eps NULL or numeric value which determines the step size to use when
 #' calculating numerical derivatives: (f(x+eps)-f(x))/eps. When `eps` is
@@ -136,23 +142,8 @@
 #' @template parallel
 #' @template order_of_operations
 #' @template options
-#'
-#' @return A `data.frame` with one row per observation (per term/group) and several columns:
-#' * `rowid`: row number of the `newdata` data frame
-#' * `type`: prediction type, as defined by the `type` argument
-#' * `group`: (optional) value of the grouped outcome (e.g., categorical outcome models)
-#' * `term`: the variable whose marginal effect is computed
-#' * `dydx`: slope of the outcome with respect to the term, for a given combination of predictor values
-#' * `std.error`: standard errors computed by via the delta method.
-#' * `p.value`: p value associated to the `estimate` column. The null is determined by the `hypothesis` argument (0 by default), and p values are computed before applying the `transform` argument. For models of class `feglm`, `Gam`, `glm` and `negbin`, p values are computed on the link scale by default unless the `type` argument is specified explicitly.
-#' * `s.value`: Shannon information transforms of p values. How many consecutive "heads" tosses would provide the same amount of evidence (or "surprise") against the null hypothesis that the coin is fair? The purpose of S is to calibrate the analyst's intuition about the strength of evidence encoded in p against a well-known physical phenomenon. See Greenland (2019) and Cole et al. (2020).
-#' * `conf.low`: lower bound of the confidence interval (or equal-tailed interval for bayesian models)
-#' * `conf.high`: upper bound of the confidence interval (or equal-tailed interval for bayesian models)
-#'
-#' See `?print.marginaleffects` for printing options.
-#'
+#' @template return
 #' @examplesIf interactive() || isTRUE(Sys.getenv("R_DOC_BUILD") == "true")
-#' @examples
 #' # Unit-level (conditional) Marginal Effects
 #' mod <- glm(am ~ hp * wt, data = mtcars, family = binomial)
 #' mfx <- slopes(mod)
@@ -234,97 +225,102 @@ slopes <- function(model,
                    wts = FALSE,
                    hypothesis = NULL,
                    equivalence = NULL,
-                   p_adjust = NULL,
                    df = Inf,
                    eps = NULL,
                    numderiv = "fdforward",
                    ...) {
-  dots <- list(...)
 
-  # very early, before any use of newdata
-  # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
-  scall <- rlang::enquo(newdata)
-  newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
+    call_attr <- construct_call(model, "slopes")
 
-  # build call: match.call() doesn't work well in *apply()
-  call_attr <- c(
-    list(
-      name = "slopes",
-      model = model,
-      newdata = newdata,
-      variables = variables,
-      type = type,
-      vcov = vcov,
-      by = by,
-      conf_level = conf_level,
-      slope = slope,
-      wts = wts,
-      hypothesis = hypothesis,
-      df = df,
-      eps = eps),
-    list(...))
-  call_attr <- do.call("call", call_attr)
+    # very early, before any use of newdata
+    # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
+    # scall <- rlang::enquo(newdata)
+    # newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
 
-  # slopes() does not support a named list of variables like comparisons()
-  checkmate::assert_character(variables, null.ok = TRUE)
+    # build call: match.call() doesn't work well in *apply()
+    # call_attr <- c(
+    #     list(
+    #         name = "slopes",
+    #         model = model,
+    #         newdata = newdata,
+    #         variables = variables,
+    #         type = type,
+    #         vcov = vcov,
+    #         by = by,
+    #         conf_level = conf_level,
+    #         slope = slope,
+    #         wts = wts,
+    #         hypothesis = hypothesis,
+    #         df = df,
+    #         eps = eps),
+    #     list(...))
+    # call_attr <- do.call("call", call_attr)
 
-  # slope
-  valid <- c("dydx", "eyex", "eydx", "dyex", "dydxavg", "eyexavg", "eydxavg", "dyexavg")
-  checkmate::assert_choice(slope, choices = valid)
+    # slopes() does not support a named list of variables like comparisons()
+    checkmate::assert_character(variables, null.ok = TRUE)
 
-  # sanity checks and pre-processing
-  model <- sanitize_model(model = model, newdata = newdata, wts = wts, vcov = vcov, by = by, calling_function = "marginaleffects", ...)
-  sanity_dots(model = model, calling_function = "marginaleffects", ...)
-  type <- sanitize_type(model = model, type = type, calling_function = "slopes")
+    # slope
+    valid <- c("dydx", "eyex", "eydx", "dyex", "dydxavg", "eyexavg", "eydxavg", "dyexavg")
+    checkmate::assert_choice(slope, choices = valid)
 
-  ############### sanity checks are over
+    # sanity checks and pre-processing
+    model <- sanitize_model(model = model, wts = wts, vcov = vcov, by = by, calling_function = "marginaleffects", ...)
+    sanity_dots(model = model, calling_function = "marginaleffects", ...)
+    type <- sanitize_type(model = model, type = type, calling_function = "slopes")
 
-  # Bootstrap
-  out <- inferences_dispatch(
-    INF_FUN = slopes,
-    model = model, newdata = newdata, vcov = vcov, variables = variables, type = type,
-    conf_level = conf_level,
-    by = by,
-    wts = wts, slope = slope, hypothesis = hypothesis, ...)
-  if (!is.null(out)) {
+    ############### sanity checks are over
+
+    # Bootstrap
+    out <- inferences_dispatch(
+        INF_FUN = slopes,
+        model = model, newdata = newdata, vcov = vcov, variables = variables, type = type,
+        conf_level = conf_level,
+        by = by,
+        wts = wts, slope = slope, hypothesis = hypothesis, ...)
+    if (!is.null(out)) {
+        return(out)
+    }
+
+    call_attr_c <- call_attr
+    call_attr_c[[1L]] <- quote(marginaleffects::comparisons)
+    call_attr_c[["model"]] <- model
+    call_attr_c[["type"]] <- type
+    call_attr_c[["comparison"]] <- slope
+    call_attr_c[["cross"]] <- FALSE
+    call_attr_c[["internal_call"]] <- TRUE
+    call_attr_c[["slope"]] <- NULL
+
+    # out <- comparisons(
+    #     model,
+    #     newdata = newdata,
+    #     variables = variables,
+    #     vcov = vcov,
+    #     conf_level = conf_level,
+    #     type = type,
+    #     wts = wts,
+    #     hypothesis = hypothesis,
+    #     equivalence = equivalence,
+    #     df = df,
+    #     by = by,
+    #     eps = eps,
+    #     numderiv = numderiv,
+    #     comparison = slope,
+    #     cross = FALSE,
+    #     # secret arguments
+    #     internal_call = TRUE,
+    #     ...)
+
+    out <- eval.parent(call_attr_c)
+
+    if (!is.null(attr(out, "call"))) {
+        attr(out, "call") <- call_attr
+    }
+
+    # class
+    data.table::setDF(out)
+    class(out) <- setdiff(class(out), "comparisons")
+    class(out) <- c("slopes", "marginaleffects", class(out))
     return(out)
-  }
-
-  out <- comparisons(
-    model,
-    newdata = newdata,
-    variables = variables,
-    vcov = vcov,
-    conf_level = conf_level,
-    type = type,
-    wts = wts,
-    hypothesis = hypothesis,
-    equivalence = equivalence,
-    df = df,
-    p_adjust = p_adjust,
-    by = by,
-    eps = eps,
-    numderiv = numderiv,
-    comparison = slope,
-    cross = FALSE,
-    # secret arguments
-    internal_call = TRUE,
-    ...)
-
-  data.table::setDT(out)
-
-  lean = getOption("marginaleffects_lean", default = FALSE)
-  if (!isTRUE(lean)) {
-    attr(out, "vcov.type") <- get_vcov_label(vcov)
-    attr(out, "newdata") <- newdata # recall
-    attr(out, "call") <- call_attr
-  }
-
-  # class
-  data.table::setDF(out)
-  class(out) <- setdiff(class(out), "comparisons")
-  class(out) <- c("slopes", "marginaleffects", class(out))
-  return(out)
 }
 
 
@@ -345,46 +341,48 @@ avg_slopes <- function(model,
                        wts = FALSE,
                        hypothesis = NULL,
                        equivalence = NULL,
-                       p_adjust = NULL,
                        df = Inf,
                        eps = NULL,
                        numderiv = "fdforward",
                        ...) {
-  # order of the first few paragraphs is important
-  # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
-  # should probably not be nested too deeply in the call stack since we eval.parent() (not sure about this)
-  scall <- rlang::enquo(newdata)
-  newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
+    # order of the first few paragraphs is important
+    # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
+    # should probably not be nested too deeply in the call stack since we eval.parent() (not sure about this)
+    # scall <- rlang::enquo(newdata)
+    # newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
 
 
-  # Bootstrap
-  out <- inferences_dispatch(
-    INF_FUN = avg_slopes,
-    model = model, newdata = newdata, vcov = vcov, variables = variables, type = type,
-    conf_level = conf_level, by = by,
-    wts = wts, slope = slope, hypothesis = hypothesis, ...)
-  if (!is.null(out)) {
+    # Bootstrap
+    out <- inferences_dispatch(
+        INF_FUN = avg_slopes,
+        model = model, newdata = newdata, vcov = vcov, variables = variables, type = type,
+        conf_level = conf_level, by = by,
+        wts = wts, slope = slope, hypothesis = hypothesis, ...)
+    if (!is.null(out)) {
+        return(out)
+    }
+
+    #Construct comparisons() call
+    call_attr <- construct_call(model, "slopes")
+
+    out <- eval.parent(call_attr)
+
+    # out <- slopes(
+    #     model = model,
+    #     newdata = newdata,
+    #     variables = variables,
+    #     type = type,
+    #     vcov = vcov,
+    #     conf_level = conf_level,
+    #     by = by,
+    #     slope = slope,
+    #     wts = wts,
+    #     hypothesis = hypothesis,
+    #     equivalence = equivalence,
+    #     df = df,
+    #     eps = eps,
+    #     numderiv = numderiv,
+    #     ...)
+
     return(out)
-  }
-
-
-  out <- slopes(
-    model = model,
-    newdata = newdata,
-    variables = variables,
-    type = type,
-    vcov = vcov,
-    conf_level = conf_level,
-    by = by,
-    slope = slope,
-    wts = wts,
-    hypothesis = hypothesis,
-    equivalence = equivalence,
-    p_adjust = p_adjust,
-    df = df,
-    eps = eps,
-    numderiv = numderiv,
-    ...)
-
-  return(out)
 }
